@@ -17,8 +17,7 @@ import json
 import datetime
 import time
 
-# my
-import timezone
+import pytz
 
 
 class Nowfm(object):
@@ -99,5 +98,5 @@ class Nowfm(object):
         曲の再生開始時刻を表す文字列をLast.fmの形式に合わせて整形する
         UNIX timestamp -> UTC datetime -> formatted UTC datetime
         """
-        d = datetime.datetime.fromtimestamp(uts, tz=timezone.utc)
+        d = datetime.datetime.fromtimestamp(uts, tz=pytz.utc)
         return d.strftime('%d %b %Y, %H:%M')
